Enum ContentPurpose
#[non_exhaustive]#[repr(u32)]pub enum ContentPurpose {
Show 13 variants
Normal = 0,
Alpha = 1,
Digits = 2,
Number = 3,
Phone = 4,
Url = 5,
Email = 6,
Name = 7,
Password = 8,
Date = 9,
Time = 10,
Datetime = 11,
Terminal = 12,
}Available on crate feature
wayland and Linux only.Expand description
content purpose
The content purpose allows to specify the primary purpose of a text input.
This allows an input method to show special purpose input panels with extra characters or to disallow some characters.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Normal = 0
default input, allowing all characters
Alpha = 1
allow only alphabetic characters
Digits = 2
allow only digits
Number = 3
input a number (including decimal separator and sign)
Phone = 4
input a phone number
Url = 5
input an URL
Email = 6
input an email address
Name = 7
input a name of a person
Password = 8
input a password (combine with password or sensitive_data hint)
Date = 9
input a date
Time = 10
input a time
Datetime = 11
input a date and time
Terminal = 12
input for a terminal