#[non_exhaustive]
pub enum Request<'a> { Activate { seat: WlSeat, surface: WlSurface, }, Deactivate { seat: WlSeat, }, ShowInputPanel, HideInputPanel, Reset, SetSurroundingText { text: String, cursor: u32, anchor: u32, }, SetContentType { hint: WEnum<ContentHint>, purpose: WEnum<ContentPurpose>, }, SetCursorRectangle { x: i32, y: i32, width: i32, height: i32, }, SetPreferredLanguage { language: String, }, CommitState { serial: u32, }, InvokeAction { button: u32, index: u32, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Activate

request activation

Requests the text_input object to be activated (typically when the text entry gets focus).

The seat argument is a wl_seat which maintains the focus for this activation. The surface argument is a wl_surface assigned to the text_input object and tracked for focus lost. The enter event is emitted on successful activation.

Fields

seat: WlSeat
surface: WlSurface


Deactivate

request deactivation

Requests the text_input object to be deactivated (typically when the text entry lost focus). The seat argument is a wl_seat which was used for activation.

Fields

seat: WlSeat


ShowInputPanel

show input panels

Requests input panels (virtual keyboard) to show.



HideInputPanel

hide input panels

Requests input panels (virtual keyboard) to hide.



Reset

reset

Should be called by an editor widget when the input state should be reset, for example after the text was changed outside of the normal input method flow.



SetSurroundingText

sets the surrounding text

Sets the plain surrounding text around the input position. Text is UTF-8 encoded. Cursor is the byte offset within the surrounding text. Anchor is the byte offset of the selection anchor within the surrounding text. If there is no selected text anchor, then it is the same as cursor.

Fields

text: String
cursor: u32
anchor: u32


SetContentType

set content purpose and hint

Sets the content purpose and content hint. While the purpose is the basic purpose of an input field, the hint flags allow to modify some of the behavior.

When no content type is explicitly set, a normal content purpose with default hints (auto completion, auto correction, auto capitalization) should be assumed.



SetCursorRectangle

Fields

width: i32
height: i32


SetPreferredLanguage

sets preferred language

Sets a specific language. This allows for example a virtual keyboard to show a language specific layout. The “language” argument is an RFC-3066 format language tag.

It could be used for example in a word processor to indicate the language of the currently edited document or in an instant message application which tracks languages of contacts.

Fields

language: String


CommitState

Fields

serial: u32

used to identify the known state



InvokeAction

Fields

button: u32
index: u32

Implementations



impl<'a> Request<'a>

pub fn opcode(&self) -> u16

Get the opcode number of this message