Struct ZwpTextInputV1

pub struct ZwpTextInputV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
text input

An object used for text input. Adds support for text input and input methods to applications. A text_input object is created from a wl_text_input_manager and corresponds typically to a text entry in an application.

Requests are used to activate/deactivate the text_input object and set state information like surrounding and selected text or the content type. The information about entered text is sent to the text_input object via the pre-edit and commit events. Using this interface removes the need for applications to directly process hardware key events and compose text out of them.

Text is generally UTF-8 encoded, indices and lengths are in bytes.

Serials are used to synchronize the state between the text input and an input method. New serials are sent by the text input in the commit_state request and are used by the input method to indicate the known text input state in events like preedit_string, commit_string, and keysym. The text input can then ignore events from the input method which are based on an outdated state (for example after a reset).

Warning! The protocol described in this file is experimental and backward incompatible changes may be made. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes are done by bumping the version number in the protocol and interface names and resetting the interface version. Once the protocol is to be declared stable, the ‘z’ prefix and the version number in the protocol and interface names are removed and the interface version number is reset.

See also the Event enum for this interface.

Implementations



impl ZwpTextInputV1

pub fn activate(&self, seat: &WlSeat, surface: &WlSurface)

request activation

Requests the text_input object to be activated (typically when the text entry gets focus).

The seat argument is a wl_seat which maintains the focus for this activation. The surface argument is a wl_surface assigned to the text_input object and tracked for focus lost. The enter event is emitted on successful activation.

pub fn deactivate(&self, seat: &WlSeat)

request deactivation

Requests the text_input object to be deactivated (typically when the text entry lost focus). The seat argument is a wl_seat which was used for activation.

pub fn show_input_panel(&self)

show input panels

Requests input panels (virtual keyboard) to show.

pub fn hide_input_panel(&self)

hide input panels

Requests input panels (virtual keyboard) to hide.

pub fn reset(&self)

reset

Should be called by an editor widget when the input state should be reset, for example after the text was changed outside of the normal input method flow.

pub fn set_surrounding_text(&self, text: String, cursor: u32, anchor: u32)

sets the surrounding text

Sets the plain surrounding text around the input position. Text is UTF-8 encoded. Cursor is the byte offset within the surrounding text. Anchor is the byte offset of the selection anchor within the surrounding text. If there is no selected text anchor, then it is the same as cursor.

pub fn set_content_type(&self, hint: ContentHint, purpose: ContentPurpose)

set content purpose and hint

Sets the content purpose and content hint. While the purpose is the basic purpose of an input field, the hint flags allow to modify some of the behavior.

When no content type is explicitly set, a normal content purpose with default hints (auto completion, auto correction, auto capitalization) should be assumed.

pub fn set_cursor_rectangle(&self, x: i32, y: i32, width: i32, height: i32)

pub fn set_preferred_language(&self, language: String)

sets preferred language

Sets a specific language. This allows for example a virtual keyboard to show a language specific layout. The “language” argument is an RFC-3066 format language tag.

It could be used for example in a word processor to indicate the language of the currently edited document or in an instant message application which tracks languages of contacts.

pub fn commit_state(&self, serial: u32)

pub fn invoke_action(&self, button: u32, index: u32)